@@ -39,7 +39,8 @@
 #define HAS_SYSCTL(n) (sysctlbyname(n, NULL, NULL, NULL, 0) == 0)
 #endif
 
-#define PREFIX "/sys/class/backlight/"
+#define BACKLIGHT_SYSFS_PATH "/sys/class/backlight/"
+#define LED_SYSFS_PATH "/sys/class/leds/"
 
 BacklightHelper::BacklightHelper(QObject *parent) : QObject(parent)
 {
@@ -62,24 +63,36 @@ void BacklightHelper::init()
     m_isSupported = true;
 }
 
+bool BacklightHelper::isRawBacklightEnabled(const QString &interface)
+{
+    QFile file(BACKLIGHT_SYSFS_PATH + interface + "/device/enabled");
+
+    if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+        return false;
+    }
+
+    QByteArray buffer = file.readLine().trimmed();
+    if (buffer == "enabled") {
+        return true;
+    }
+
+    return false;
+}
+
 void BacklightHelper::initUsingBacklightType()
 {
-    QDir dir(PREFIX);
-    dir.setFilter(QDir::AllDirs | QDir::NoDot | QDir::NoDotDot | QDir::NoDotAndDotDot | QDir::Readable);
-    dir.setSorting(QDir::Name | QDir::Reversed);// Reverse is needed to priorize acpi_video1 over 0
+    QDir backlightDir(BACKLIGHT_SYSFS_PATH);
+    backlightDir.setFilter(QDir::AllDirs | QDir::NoDot | QDir::NoDotDot | QDir::NoDotAndDotDot | QDir::Readable);
+    backlightDir.setSorting(QDir::Name | QDir::Reversed);// Reverse is needed to priorize acpi_video1 over 0
 
-    QStringList interfaces = dir.entryList();
-
-    if (interfaces.isEmpty()) {
-        return;
-    }
+    QStringList interfaces = backlightDir.entryList();
 
     QFile file;
     QByteArray buffer;
-    QStringList firmware, platform, raw;
+    QStringList firmware, platform, raw, leds;
 
     Q_FOREACH(const QString & interface, interfaces) {
-        file.setFileName(PREFIX + interface + "/type");
+        file.setFileName(BACKLIGHT_SYSFS_PATH + interface + "/type");
         if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
             continue;
         }
@@ -90,7 +103,9 @@ void BacklightHelper::initUsingBacklightType()
         } else if(buffer == "platform") {
             platform.append(interface);
         } else if (buffer == "raw") {
-            raw.append(interface);
+            if (isRawBacklightEnabled(interface)) {
+                raw.append(interface);
+            }
         } else {
             qCWarning(POWERDEVIL) << "Interface type not handled" << buffer;
         }
@@ -98,20 +113,32 @@ void BacklightHelper::initUsingBacklightType()
         file.close();
     }
 
+    QDir ledsDir(LED_SYSFS_PATH);
+    ledsDir.setFilter(QDir::Dirs | QDir::NoDot | QDir::NoDotDot | QDir::NoDotAndDotDot | QDir::Readable);
+    ledsDir.setNameFilters({QStringLiteral("*lcd*"), QStringLiteral("*wled*")});
+
+    QStringList ledInterfaces = ledsDir.entryList();
+
+    if (!ledInterfaces.isEmpty()) {
+        m_dirname = LED_SYSFS_PATH + ledInterfaces.constFirst();
+        return;
+    }
+
     if (!firmware.isEmpty()) {
-        m_dirname = PREFIX + firmware.first();
+        m_dirname = BACKLIGHT_SYSFS_PATH + firmware.constFirst();
         return;
     }
 
     if (!platform.isEmpty()) {
-        m_dirname = PREFIX + platform.first();
+        m_dirname = BACKLIGHT_SYSFS_PATH + platform.constFirst();
         return;
     }
 
     if (!raw.isEmpty()) {
-        m_dirname = PREFIX + raw.first();
+        m_dirname = BACKLIGHT_SYSFS_PATH + raw.constFirst();
         return;
     }
+
 }
 
 void BacklightHelper::initUsingSysctl()
